Exception: Redlics::Exception::LuaRangeError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/redlics/exception.rb

Overview

Lua Range Error class

Maximal Lua stack size for the method unpack is by default 8000. To change this parameter in Redis an own make and build of Redis is needed.

Instance Method Summary collapse

Constructor Details

#initialize(msg = 'Too many keys (max. 8000 keys defined by LUAI_MAXCSTACK)') ⇒ Redlics::Exception::LuaRangeError

Initialization with default error message.

Parameters:

  • msg (String) (defaults to: 'Too many keys (max. 8000 keys defined by LUAI_MAXCSTACK)') —

    the error message



21
22
23
# File 'lib/redlics/exception.rb', line 21

def initialize(msg = 'Too many keys (max. 8000 keys defined by LUAI_MAXCSTACK)')
  super(msg)
end