Exception: Redlics::Exception::LuaRangeError
- Inherits:
-
StandardError
- Object
- StandardError
- Redlics::Exception::LuaRangeError
- Defined in:
- lib/redlics/exception.rb
Overview
Lua Range Error class
Maximal Lua stack size for the method unpack is by default 8000.
To change this parameter in Redis an own make and build of Redis is needed.
Instance Method Summary collapse
-
#initialize(msg = 'Too many keys (max. 8000 keys defined by LUAI_MAXCSTACK)') ⇒ Redlics::Exception::LuaRangeError
constructor
Initialization with default error message.
Constructor Details
#initialize(msg = 'Too many keys (max. 8000 keys defined by LUAI_MAXCSTACK)') ⇒ Redlics::Exception::LuaRangeError
Initialization with default error message.
21 22 23 |
# File 'lib/redlics/exception.rb', line 21 def initialize(msg = 'Too many keys (max. 8000 keys defined by LUAI_MAXCSTACK)') super(msg) end |